@@ -28,6 +28,8 @@
 /* avoid conflicting definition; __STDC_VERSION__ is not defined with ports gcc */
 #if defined(__OpenBSD__) || (defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)
 #  include <stdint.h>
+#elif defined(__sun) && defined(__SVR4)
+#  include <inttypes.h>
 #else
 typedef   signed char      int8_t;	/* 8-bit int */
 typedef unsigned char     uint8_t;	/* 8-bit int */
@@ -56,10 +58,10 @@ typedef unsigned char     uint8_t;	/* 8-bit int */
   typedef unsigned  short  uint16_t;	/* 16-bit int */
   typedef   signed  int   int32_t;	/* 32-bit int */
   typedef unsigned  int  uint32_t;	/* 32-bit int */
-  typedef   signed  long   int64_t;	/* 64-bit int */
-  typedef unsigned  long  uint64_t;	/* 64-bit int */
-  typedef   signed long  intptr_t;
-  typedef unsigned long uintptr_t;
+  typedef   signed  long long   int64_t;	/* 64-bit int */
+  typedef unsigned  long long  uint64_t;	/* 64-bit int */
+  typedef   signed int  intptr_t;
+  typedef unsigned int uintptr_t;
 #  endif
 #endif
 
